******************************************************************
**** Introduction to Complex Survey Data Analysis Using Stata ****
* 
* Chelsea Goforth
* Statistical Consulting Associate
* StatLab: Statistics and Data Analysis
* University of Virginia
* cag5fk@virginia.edu
* statlab@virginia.edu
* http://data.library.virginia.edu/statlab/
*
******************************************************************


/* *****
I am indebted to Steven Heeringa, Brady West, and Patricia Berglund (Institute 
for Social Research, University of Michigan) for many useful ideas and examples 
used throughout this presentation.  For more details, you should pick up their 
recent book "Applied Survey Data Analysis" -- a fantastic resource for both 
novice and veteran survey data analysts alike.
***** */


***********************************
*** DECLARING THE SURVEY DESIGN ***
***********************************

/* Let's start with a fictious national survey designed to assess support for a 
new initiative and incorporating multistage sample. */

use http://www.stata.com/videos13/data/polldata.dta, clear

describe

/* Note that State, County, City, and Id represent the first, second, third, and 
fourth stage sampling, respectively. In other words, State represents the PSU, 
then counties were selected from within each state, then cities were selected 
within each county, and individuals were selected from within each city. If we 
selected everyone within a city, specifying this fourth stage would be unnecessary, 
but since individuals were sampled, we do need to specify in this case. */

svyset State [pweight=SampleWeights], strata(RedBlue) fpc(fpc_state) vce(linearized) singleunit(missing) /// 
	|| County, strata(RuralUrban) fpc(fpc_county) /// 
	|| City, strata(LargeSmall) fpc(fpc_city) /// 
	|| Id

/* Deconstructing the above command: 
	- each of the sampling stanges are separated by a double vertical bar
	- within each of the double vertical bars we can tell Stata about the strata 
	and FPCs associated with each stage of the sampling design
	- in addition, pweight (in the square brackets) specifies the variable name 
	containing the sampling weights (associated with the PSU)
	- vce(linearized) specifies the method for variance estimation; this is the 
	default, but other common specifications include bootstrap, brr, & jackknife, 
	(nonparametric methods for computing sampling variance of survey estimates)
	- singleunit(missing) specifies how Stata should handle strata with only one 
	sampling unit; again, this is the default, and it results in missing values 
	for the standard errors, but you might also specify singleunit(certainty), 
	singleunit(scaled), or singleunit(centered); see -help svyset- for more.

Now we can use any of our survey commands and Stata will automatically adjust 
the analysis for the characteristics of the sampling design.
*/

svyset // to display the current survey settings

*************************************************
*** DESCRIPTIVE STATS & INTRODUCTORY ANALYSES ***
*************************************************

/* Switching between data sets:  
	1.  National Comorbidity Survey Replication (NCS-R)
	2.  National Health and Nutrition Examination Survey (NHANES) 2005, 2006

The NCS-R is a 2002 study of mental illness in U.S. household population ages 18+; 
includes interviews with randomly chosen adults in an equal probability, multistage 
sample of households.

NHANES is a survey of the adult, noninstitutionalized U.S. population sponsored 
by the NCHS and the CDC; includes an in-home medical history interview and detailed 
medical examination at a local mobile examination center; conducted periodically 
between 1971 and 1994 and transitioned to a continuous interviewing design in 1999; 
beginning in 1999, collected yearly and involves a multistage sample that includes 
15 primary stage unit (PSU) locations with new sample PSUs added in each data 
collection year; approx. 7,000 probability sample interview respondents each year, 
with ~5,000 of these consenting to the physical exam; oversamples low-income 
persons, adolescents between the ages of 12 and 19, persons aged 60+, African 
Americans, and Hispanics of Mexican ancestry.
*/

cd "C:\Users\Chelsea\Dropbox\U-VIRGINIA\StatLab\Workshops\6_Fall 2015 StatLab Workshops\2_Survey Analysis\working file"

use ncsr.dta, clear
svyset seclustr [pweight=ncsrwtlg], strata(sestrat) vce(linearized) singleunit(missing)

svydes // to describe the survey data (defaults to stage 1 description)
/* The above command produces output describing the frequency distributions of 
the design variables. */

*** Summary/Frequency Statistics:

/* First, unweighted estimation of the propotions of NCS-R Part II respondents 
with lifetime diagnoses of either major depressive episode (mde), measured by a 
binary indicator equal to 0 or 1, or alcohol dependence (ald), also a binary 
indicator: */
mean mde ald if ncsrwtlg != .

/* Now we're requesting weighted estimates of these proportions by issuing the 
same command, but preceeded by -svy:- to tell Stata to use the specified design 
characteristics: */
svy: mean mde ald if ncsrwtlg != . // how do they compare?

svy: mean hhinc // estimating the mean value of houshold income
estat effects // postestimation statistics; see -help svy_estat- for more

/* Suppose we want to estimate the total number of individuals who have experienced 
a lifetime major depressive episode along with a standard error and confidence 
interval. Because the NCS-R contains normalized values of the NCSRWTSH variable 
so that the weights would sum to the sample size, the weight values must be 
expanded back to the population scale to obtain an unbiased estimate of the 
population total; we do this by multiplying the Part 1 weight for each case by 
the ratio of the NCS-R survey population total: */
gen ncsrwtsh_pop = ncsrwtsh * (209128094 / 9282)
svyset seclustr [pweight = ncsrwtsh_pop], strata(sestrat)

svy: total mde
estat effects

/* Weighted estimates of population totals can also be computed for subpopulations; 
in this case, a corrected unconditional subpopulation analysis gives us the same 
analysis by categories of marital status. */
la de mar3cat 1 "Married" 2 "Sep./Wid./Div." 3 "Never Married"
la val mar3cat mar3cat
svy: total mde, over(mar3cat) // 
estat effects

use nhanes.dta, clear
svyset sdmvpsu [pweight=wtmec2yr], strata(sdmvstra)

* mean systolic blood pressure for male and female adults over age 45
svy, subpop(if ridageyr > 45): mean bpxsy1, over(riagendr)
estat effects

/* Be aware that restricting analysis to subpopulations may result in a reduction 
in the effective degrees of freedom for variance estimation. */
svy: mean bpxsy1, subpop(if ridageyr > 80 & ridreth1==4) over(edcat)

/* In the next analysis, we will estimate the proportion of the U.S. Adult 
Population with an irregular heartbeat. */
svy, subpop(age18p): tab irregular, se ci col deff // CI based on logit transform technique
svy, subpop(age18p): proportion irregular // CI computed using the standard symmetric interval
svy, subpop(age18p): mean irregular // CI computed using the standard symmetric interval

/* Now let's estimate total and row proportions for the cross-tabulation of gender 
and lifetime major depression status: */
use ncsr.dta, clear
svyset seclustr [pweight=ncsrwtlg], strata(sestrat)

svy: tab sex mde, se ci deff // total proportions (M, w/ & w/o MDE; F, w/ & w/o MDE)
svy: tab sex mde, row se ci deff // row proportions (no MDE|Male, MDE|M, no MDE|Female, MDE|F)

/* Is there a difference in the proportions of U.S. adult men and women with a 
lifetime diagnosis of a major depressive episode? */
svy: proportion mde, over(sex)

/* Internally, Stata labels the estimated row proportions for MDE = 1 as _prop_2; 
we can use this and the -lincom- command to estimate the difference: */
lincom [_prop_2]1 - [_prop_2]2

/* Because the 95% CI for the difference in proportion does not include 0, the 
data suggest that the rate of lifetime major depressive episodes for women is 
significantly higher than that for men. */

*** Linear Regression:
use nhanes.dta, clear
svyset sdmvpsu [pweight=wtmec2yr], strata(sdmvstra)

/*First, we compute a weighted estimate of the mean age for the adult subclass 
and then center the AGE variable at the weighted mean age based on the sample (45.6): */
svy: mean age [pweight=wtmec2yr] if age18p==1
generate agec = age - 45.60

* bivariate:
svy, subpop(age18p): regress bpxdi1_1 i.ridreth1 // -i.- preceeds categorical variables in regression

svy, subpop(age18p): regress bpxdi1_1 i.ridreth1, coeflegend // provides underlying legend
test _b[2.ridreth1]=_b[4.ridreth1]

* multivariate:
svy, subpop(age18p): regress bpxdi1_1 i.ridreth1 i.marcat i.riagendr ridageyr
estat effects, deff // design effects for the estimated regression parameters

predict resids, resid
scatter resids ridageyr // model misspecification: curvilinear pattern of residuals as a function of age

svy, subpop(age18p): regress bpxdi1_1 i.ridreth1 i.marcat i.riagendr c.ridageyr c.ridageyr#c.ridageyr

***********************
*** SIMPLE GRAPHICS ***
***********************

use nhanes.dta, clear

* weighted histogram of total cholesterol measures:
svy: hist lbxtc if age18p // oops!
gen int_wtmec2yr = int(wtmec2yr) // note that Stata requires frequency weight be specified as integer
hist lbxtc if age18p [fweight=int_wtmec2yr]

* weighted boxplots of total cholesterol by gender:
graph box lbxtc [pweight=wtmec2yr] if age18p==1, by(riagendr)

* scatterplot of the relationship between high-density lipoprotein and total serum cholesterol:
twoway (scatter lbdhdd lbxtc if age18p==1) (lfit lbdhdd lbxtc if age18p==1 [pweight=wtmec2yr])

* vertical bar chart of estimated blood pressure status classification for U.S. adults:
gen bp_cat1 = (bpxsy1 < 120 & bpxdi1 < 80)
gen bp_cat2 = (bpxsy1 >= 120 & bpxsy1 < 140) | (bpxdi1 >= 80 & bpxdi1 < 90)
gen bp_cat3 = (bpxsy1 >= 140 & bpxsy1 < 160) | (bpxdi1 >= 90 & bpxdi1 < 100)
gen bp_cat4 = (bpxsy1 >= 160 & bpxsy1 != .) | (bpxdi1 >= 90 & bpxdi1 < 100)

graph bar (mean) bp_cat1 bp_cat2 bp_cat3 bp_cat4 [pweight=wtmec2yr] if age18p==1, /// 
	blabel(bar, format(%9.1f) color(none)) bar(1,color(gs12)) bar(2,color(gs4)) /// 
	bar(3,color(gs8)) bar(4,color(black)) bargap(7) scheme(s2mono) over(riagendr) /// 
	percentages legend (label(1 "Normal") label(2 "Pre-Hypertensive") /// 
	label(3 "Stage 1 Hypertensive") label(4 "Stage 2 Hypertensive")) ytitle("Percentage")
